@@ -7,6 +7,7 @@ from sqlalchemy.dialects import postgresql
 from twisted.internet.defer import Deferred, inlineCallbacks
 from vortex.DeferUtil import vortexLogFailure
 from vortex.Payload import Payload
+from vortex.PayloadEnvelope import PayloadEnvelope
 from vortex.VortexFactory import VortexFactory, NoVortexException
 
 from peek_abstract_chunked_index.private.tuples.ACIEncodedChunkTupleABC import (
@@ -58,14 +59,17 @@ class ACIChunkUpdateHandlerABC(metaclass=ABCMeta):
         )
         if not vortexNamesToSendTo:
             self._logger.debug(
-                "No clients are online to send the chunked chunk to, %s", chunkKeys
+                "No clients are online to send the chunked chunk to, %s",
+                chunkKeys,
             )
             return
 
         def send(vortexMsg: bytes):
             if vortexMsg:
                 for vortexName in vortexNamesToSendTo:
-                    VortexFactory.sendVortexMsg(vortexMsg, destVortexName=vortexName)
+                    VortexFactory.sendVortexMsg(
+                        vortexMsg, destVortexName=vortexName
+                    )
 
         d: Deferred = self._loadChunks(chunkKeys)
         d.addCallback(send)
@@ -75,7 +79,8 @@ class ACIChunkUpdateHandlerABC(metaclass=ABCMeta):
 
         if failure.check(NoVortexException):
             self._logger.debug(
-                "No clients are online to send the chunked chunk to, %s", chunkKeys
+                "No clients are online to send the chunked chunk to, %s",
+                chunkKeys,
             )
             return
 
@@ -87,7 +92,11 @@ class ACIChunkUpdateHandlerABC(metaclass=ABCMeta):
         assert chunkKeys, "we must have some chunkKeys"
 
         encodedPayload = yield runPyInPg(
-            self._logger, self._dbSessionCreator, self._loadChunksInPg, None, chunkKeys
+            self._logger,
+            self._dbSessionCreator,
+            self._loadChunksInPg,
+            None,
+            chunkKeys,
         )
 
         return encodedPayload.encode()
@@ -116,7 +125,8 @@ class ACIChunkUpdateHandlerABC(metaclass=ABCMeta):
 
         sqlQry = str(
             sql.compile(
-                dialect=postgresql.dialect(), compile_kwargs={"literal_binds": True}
+                dialect=postgresql.dialect(),
+                compile_kwargs={"literal_binds": True},
             )
         )
 
@@ -146,17 +156,20 @@ class ACIChunkUpdateHandlerABC(metaclass=ABCMeta):
         # ---------------
         # Process the results, create blank grids where the grid has been deleted
 
-        deletedChunkKeys = set(chunkKeys) - set([r.ckiChunkKey for r in results])
+        deletedChunkKeys = set(chunkKeys) - set(
+            [r.ckiChunkKey for r in results]
+        )
 
         for chunkKey in deletedChunkKeys:
-            results.append(cls._ChunkedTuple.ckiCreateDeleteEncodedChunk(chunkKey))
+            results.append(
+                cls._ChunkedTuple.ckiCreateDeleteEncodedChunk(chunkKey)
+            )
 
         if not results:
             return None
 
         return (
-            Payload(filt=cls._updateFromServerFilt, tuples=results)
-            .makePayloadEnvelope(compressionLevel=3)
+            PayloadEnvelope(filt=cls._updateFromServerFilt, data=results)
             .toVortexMsg()
             .decode()
         )
