@@ -10,7 +10,10 @@ from typing import List, Deque, Callable, Optional
 
 import psutil
 import pytz
-from psycopg2.extensions import ISOLATION_LEVEL_AUTOCOMMIT, ISOLATION_LEVEL_DEFAULT
+from psycopg2.extensions import (
+    ISOLATION_LEVEL_AUTOCOMMIT,
+    ISOLATION_LEVEL_DEFAULT,
+)
 from sqlalchemy import select, asc
 from sqlalchemy.dialects import postgresql
 from twisted.internet import task, reactor, defer
@@ -28,10 +31,12 @@ from peek_abstract_chunked_index.private.server.controller.ACIProcessorStatusNot
 from peek_abstract_chunked_index.private.tuples.ACIProcessorQueueTupleABC import (
     ACIProcessorQueueTupleABC,
 )
+from peek_plugin_base.LoopingCallUtil import peekCatchErrbackWithLogger
 from peek_plugin_base.storage.RunPyInPg import runPyInPg
 
 ACIProcessorQueueBlockItem = namedtuple(
-    "ACIProcessorQueueBlockItem", ("queueIds", "itemsEncodedPayload", "itemUniqueIds")
+    "ACIProcessorQueueBlockItem",
+    ("queueIds", "itemsEncodedPayload", "itemUniqueIds"),
 )
 
 
@@ -86,10 +91,12 @@ class ACIProcessorQueueControllerABC(metaclass=ABCMeta):
         )
         self._isProcessorEnabledCallable = isProcessorEnabledCallable
 
-        self._pollLoopingCall = task.LoopingCall(self._poll)
-        self._nextVacuumTime = datetime.now(pytz.utc) + self._randomiseTimeDelta(
-            self.VACUUM_PERIOD_SECONDS
+        self._pollLoopingCall = task.LoopingCall(
+            peekCatchErrbackWithLogger(self._logger)(self._poll)
         )
+        self._nextVacuumTime = datetime.now(
+            pytz.utc
+        ) + self._randomiseTimeDelta(self.VACUUM_PERIOD_SECONDS)
         self._queueCount = 0
 
         self._queueIdsInBuffer = set()
@@ -104,7 +111,9 @@ class ACIProcessorQueueControllerABC(metaclass=ABCMeta):
         assert self.QUEUE_ITEMS_PER_TASK, "ACI, QUEUE_ITEMS_PER_TASK is missing"
         assert self.POLL_PERIOD_SECONDS, "ACI, POLL_PERIOD_SECONDS is missing"
         assert self.QUEUE_BLOCKS_MAX, "ACI, QUEUE_BLOCKS_MAX is missing"
-        assert self.QUEUE_BLOCKS_MIN is not None, "ACI, QUEUE_BLOCKS_MIN is missing"
+        assert (
+            self.QUEUE_BLOCKS_MIN is not None
+        ), "ACI, QUEUE_BLOCKS_MIN is missing"
         assert self.WORKER_TASK_TIMEOUT, "ACI, WORKER_TASK_TIMEOUT is missing"
         assert self._logger, "ACI, _logger is missing"
         assert self._QueueDeclarative, "ACI, _QueueDeclarative is missing"
@@ -112,7 +121,9 @@ class ACIProcessorQueueControllerABC(metaclass=ABCMeta):
             self.DEDUPE_LOOK_AHEAD_MIN_ROWS
         ), "ACI, DEDUPE_LOOK_AHEAD_MIN_ROWS is missing"
         assert self._VacuumDeclaratives, "ACI, _VacuumDeclaratives is missing"
-        assert self.VACUUM_PERIOD_SECONDS, "ACI, VACUUM_PERIOD_SECONDS is missing"
+        assert (
+            self.VACUUM_PERIOD_SECONDS
+        ), "ACI, VACUUM_PERIOD_SECONDS is missing"
 
     def _randomiseTimeDelta(self, seconds: int) -> timedelta:
         # Randomise the time delta by up to +/- 20%
@@ -132,11 +143,15 @@ class ACIProcessorQueueControllerABC(metaclass=ABCMeta):
 
     def _timerErrback(self, failure):
         vortexLogFailure(failure, self._logger)
-        self._processorStatusNotifier.setProcessorStatus(False, self._queueCount)
+        self._processorStatusNotifier.setProcessorStatus(
+            False, self._queueCount
+        )
         self._processorStatusNotifier.setProcessorError(str(failure.value))
 
     def _timerCallback(self, _):
-        self._processorStatusNotifier.setProcessorStatus(False, self._queueCount)
+        self._processorStatusNotifier.setProcessorStatus(
+            False, self._queueCount
+        )
 
     def stop(self):
         if self._pollLoopingCall and self._pollLoopingCall.running:
@@ -153,7 +168,10 @@ class ACIProcessorQueueControllerABC(metaclass=ABCMeta):
             return
 
         # If we have a callable that can suspend this processor, then check it.
-        if self._isProcessorEnabledCallable and not self._isProcessorEnabledCallable():
+        if (
+            self._isProcessorEnabledCallable
+            and not self._isProcessorEnabledCallable()
+        ):
             return
 
         # We queue the grids in bursts, reducing the work we have to do.
@@ -235,8 +253,12 @@ class ACIProcessorQueueControllerABC(metaclass=ABCMeta):
                 self._pausedForDuplicate = None
 
             # Notify the status controller
-            self._processorStatusNotifier.setProcessorStatus(True, self._queueCount)
-            self._processorStatusNotifier.addToProcessorTotal(len(block.itemUniqueIds))
+            self._processorStatusNotifier.setProcessorStatus(
+                True, self._queueCount
+            )
+            self._processorStatusNotifier.addToProcessorTotal(
+                len(block.itemUniqueIds)
+            )
 
         except Exception as e:
             if isinstance(e, defer.TimeoutError):
@@ -284,7 +306,9 @@ class ACIProcessorQueueControllerABC(metaclass=ABCMeta):
     def _fetchBlocks(self) -> List[ACIProcessorQueueBlockItem]:
 
         dedupSql = (
-            self._dedupeQueueSql(self._lastFetchedId, self.DEDUPE_LOOK_AHEAD_MIN_ROWS)
+            self._dedupeQueueSql(
+                self._lastFetchedId, self.DEDUPE_LOOK_AHEAD_MIN_ROWS
+            )
             if self._lastFetchedId
             else None
         )
@@ -301,7 +325,9 @@ class ACIProcessorQueueControllerABC(metaclass=ABCMeta):
 
         blocks = []
         for raw in rawBlocks:
-            block = ACIProcessorQueueBlockItem(raw[0], raw[1].encode(), set(raw[2]))
+            block = ACIProcessorQueueBlockItem(
+                raw[0], raw[1].encode(), set(raw[2])
+            )
             blocks.append(block)
             self._queueIdsInBuffer.update(block.queueIds)
 
@@ -312,7 +338,11 @@ class ACIProcessorQueueControllerABC(metaclass=ABCMeta):
 
     @classmethod
     def _fetchBlocksInPg(
-        cls, plpy, queueIdsInBuffer: List[int], queueCount: int, dedupSql: Optional[str]
+        cls,
+        plpy,
+        queueIdsInBuffer: List[int],
+        queueCount: int,
+        dedupSql: Optional[str],
     ) -> List[ACIProcessorQueueBlockItem]:
         # ---------------
         # Deduplicate the queue before we fetch more
@@ -336,7 +366,8 @@ class ACIProcessorQueueControllerABC(metaclass=ABCMeta):
 
         sqlQry = str(
             sql.compile(
-                dialect=postgresql.dialect(), compile_kwargs={"literal_binds": True}
+                dialect=postgresql.dialect(),
+                compile_kwargs={"literal_binds": True},
             )
         )
 
@@ -388,9 +419,13 @@ class ACIProcessorQueueControllerABC(metaclass=ABCMeta):
                 items.append(item)
                 itemUniqueIds.append(item.ckiUniqueKey)
 
-            itemsEncodedPayload = Payload(tuples=[items, queueIds]).toEncodedPayload()
+            itemsEncodedPayload = Payload(
+                tuples=[items, queueIds]
+            ).toEncodedPayload()
 
-            queueBlocks.append((queueIds, itemsEncodedPayload.decode(), itemUniqueIds))
+            queueBlocks.append(
+                (queueIds, itemsEncodedPayload.decode(), itemUniqueIds)
+            )
 
         # Put the oldest queue blocks back at the start
         queueBlocks = list(reversed(queueBlocks))
@@ -445,12 +480,14 @@ class ACIProcessorQueueControllerABC(metaclass=ABCMeta):
         if datetime.now(pytz.utc) < self._nextVacuumTime:
             return defer.succeed(True)
 
-        self._nextVacuumTime = datetime.now(pytz.utc) + self._randomiseTimeDelta(
-            self.VACUUM_PERIOD_SECONDS
-        )
+        self._nextVacuumTime = datetime.now(
+            pytz.utc
+        ) + self._randomiseTimeDelta(self.VACUUM_PERIOD_SECONDS)
 
         return self.__vacuumSemaphore.run(
-            deferToThreadWrapWithLogger(self._logger)(self.__vacuumTablesWrapped)
+            deferToThreadWrapWithLogger(self._logger)(
+                self.__vacuumTablesWrapped
+            )
         )
 
     def __vacuumTablesWrapped(self):
@@ -475,14 +512,18 @@ class ACIProcessorQueueControllerABC(metaclass=ABCMeta):
             try:
 
                 self._logger.debug("Vacuuming Table %s.%s", schema, tableName)
-                cursor.execute('VACUUM FULL VERBOSE "%s"."%s"' % (schema, tableName))
+                cursor.execute(
+                    'VACUUM FULL VERBOSE "%s"."%s"' % (schema, tableName)
+                )
 
                 while len(rawConn.notices) < 2:
                     sleep(2.0)
                 self._logger.debug(rawConn.notices[1].replace("\n", ", "))
 
             except Exception as e:
-                self._logger.error("Vacuum failed for Table %s.%s", schema, tableName)
+                self._logger.error(
+                    "Vacuum failed for Table %s.%s", schema, tableName
+                )
                 self._logger.exception(e)
 
             finally:
